import "./TreeView.css";
import {ActionButtonGroupContext as $10401bdc118cbc90$export$33f5f2f2cb85d743} from "./ActionButtonGroup.mjs";
import {ActionMenuContext as $8bf3cd2442eb485e$export$7f4b66acaca28bd5} from "./ActionMenu.mjs";
import {centerBaseline as $1f4b04be3f24aae3$export$9d7e2342a7e53afa} from "./CenterBaseline.mjs";
import {Checkbox as $9b405e0f8095dce0$export$48513f6b9f8ce62d} from "./Checkbox.mjs";
import $4b69f02ec06b9226$export$2e2bcd8739ae039 from "./Chevron.mjs";
import {IconContext as $ac8c32e6775ddd1f$export$a49f528ae1a4d0ed} from "../icons/Icon.mjs";
import {TextContext as $8e847109a6ab556d$export$9afb8bc826b033ea} from "./Content.mjs";
import {useScale as $859432f3b3573fcb$export$a8d2043b2d807f4d} from "./utils.mjs";
import {jsx as $iOVFT$jsx, jsxs as $iOVFT$jsxs} from "react/jsx-runtime";
import {Virtualizer as $iOVFT$Virtualizer, ListLayout as $iOVFT$ListLayout, Tree as $iOVFT$Tree, TreeItem as $iOVFT$TreeItem, TreeItemContent as $iOVFT$TreeItemContent, Provider as $iOVFT$Provider, useContextProps as $iOVFT$useContextProps, ButtonContext as $iOVFT$ButtonContext, Button as $iOVFT$Button} from "react-aria-components";
import {createContext as $iOVFT$createContext, useContext as $iOVFT$useContext, useRef as $iOVFT$useRef, forwardRef as $iOVFT$forwardRef} from "react";
import {useDOMRef as $iOVFT$useDOMRef} from "@react-spectrum/utils";
import {useLocale as $iOVFT$useLocale} from "react-aria";

/*
 * Copyright 2024 Adobe. All rights reserved.
 * This file is licensed to you under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License. You may obtain a copy
 * of the License at http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under
 * the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR REPRESENTATIONS
 * OF ANY KIND, either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */ 












const $03960a2740ca2b19$var$TreeRendererContext = /*#__PURE__*/ (0, $iOVFT$createContext)({});
let $03960a2740ca2b19$var$InternalTreeContext = /*#__PURE__*/ (0, $iOVFT$createContext)({});
// TODO: the below is needed so the borders of the top and bottom row isn't cut off if the TreeView is wrapped within a container by always reserving the 2px needed for the
// keyboard focus ring. Perhaps find a different way of rendering the outlines since the top of the item doesn't
// scroll into view due to how the ring is offset. Alternatively, have the tree render the top/bottom outline like it does in Listview
const $03960a2740ca2b19$var$tree = function anonymous(props, overrides) {
    let rules = " ";
    let minHeight = false;
    let minWidth = false;
    let width = false;
    let height = false;
    let matches = (overrides || '').matchAll(/(?:^|\s)(J|G|I|H|_u|_v|_s|__A|_d|_J|z|y|B|A|_P|_9|W|_l|_A|_z|Z|N|L|F|M|K)[^\s]+/g);
    for (let p of matches){
        if (p[1] === "M") minHeight = true;
        if (p[1] === "N") minWidth = true;
        if (p[1] === "Z") width = true;
        if (p[1] === "F") height = true;
        rules += p[0];
    }
    if (props.isFocusVisible) rules += ' _Lf91';
    else rules += ' _Le91';
    rules += ' Oh91';
    rules += ' _Mc91';
    rules += ' _Kb91';
    rules += ' _4c91';
    if (!minHeight) rules += ' Ma91';
    if (!minWidth) rules += ' Na91';
    if (!width) rules += ' Za91';
    if (!height) rules += ' Fb91';
    rules += ' _Na91';
    rules += ' Pa91';
    rules += ' _oa91';
    if (props.isEmpty) rules += ' _Ca91';
    if (props.isEmpty) rules += ' eb91';
    rules += ' -lPUMEc-Zu91';
    return rules;
};
function $03960a2740ca2b19$var$TreeView(props, ref) {
    let { children: children, isDetached: isDetached, isEmphasized: isEmphasized, UNSAFE_className: UNSAFE_className, UNSAFE_style: UNSAFE_style } = props;
    let scale = (0, $859432f3b3573fcb$export$a8d2043b2d807f4d)();
    let renderer;
    if (typeof children === 'function') renderer = children;
    let domRef = (0, $iOVFT$useDOMRef)(ref);
    return /*#__PURE__*/ (0, $iOVFT$jsx)((0, $iOVFT$Virtualizer), {
        layout: (0, $iOVFT$ListLayout),
        layoutOptions: {
            rowHeight: scale === 'large' ? 50 : 40,
            gap: isDetached ? 2 : 0
        },
        children: /*#__PURE__*/ (0, $iOVFT$jsx)($03960a2740ca2b19$var$TreeRendererContext.Provider, {
            value: {
                renderer: renderer
            },
            children: /*#__PURE__*/ (0, $iOVFT$jsx)($03960a2740ca2b19$var$InternalTreeContext.Provider, {
                value: {
                    isDetached: isDetached,
                    isEmphasized: isEmphasized
                },
                children: /*#__PURE__*/ (0, $iOVFT$jsx)((0, $iOVFT$Tree), {
                    ...props,
                    style: UNSAFE_style,
                    className: (renderProps)=>(UNSAFE_className ?? '') + $03960a2740ca2b19$var$tree({
                            isDetached: isDetached,
                            ...renderProps
                        }, props.styles),
                    selectionBehavior: "toggle",
                    ref: domRef,
                    children: props.children
                })
            })
        })
    });
}
const $03960a2740ca2b19$var$selectedBackground = "[light-dark(color-mix(in srgb, light-dark(rgb(255, 255, 255), rgb(17, 17, 17)), light-dark(rgb(59, 99, 251), rgb(86, 129, 255)) 10%), color-mix(in srgb, light-dark(rgb(255, 255, 255), rgb(17, 17, 17)), light-dark(rgb(93, 137, 255), rgb(52, 91, 248)) 10%))]";
const $03960a2740ca2b19$var$selectedActiveBackground = "[light-dark(color-mix(in srgb, light-dark(rgb(255, 255, 255), rgb(17, 17, 17)), light-dark(rgb(59, 99, 251), rgb(86, 129, 255)) 15%), color-mix(in srgb, light-dark(rgb(255, 255, 255), rgb(17, 17, 17)), light-dark(rgb(93, 137, 255), rgb(52, 91, 248)) 15%))]";
const $03960a2740ca2b19$var$rowBackgroundColor = {
    default: '--s2-container-bg',
    isFocusVisibleWithin: "[color-mix(in srgb, light-dark(rgb(255, 255, 255), rgb(17, 17, 17)), light-dark(rgb(19, 19, 19), rgb(242, 242, 242)) 7%)]",
    isHovered: "[color-mix(in srgb, light-dark(rgb(255, 255, 255), rgb(17, 17, 17)), light-dark(rgb(19, 19, 19), rgb(242, 242, 242)) 7%)]",
    isPressed: "[color-mix(in srgb, light-dark(rgb(255, 255, 255), rgb(17, 17, 17)), light-dark(rgb(19, 19, 19), rgb(242, 242, 242)) 10%)]",
    isSelected: {
        default: "[color-mix(in srgb, light-dark(rgb(255, 255, 255), rgb(17, 17, 17)), light-dark(rgb(19, 19, 19), rgb(242, 242, 242)) 7%)]",
        isEmphasized: $03960a2740ca2b19$var$selectedBackground,
        isFocusVisibleWithin: {
            default: "[color-mix(in srgb, light-dark(rgb(255, 255, 255), rgb(17, 17, 17)), light-dark(rgb(19, 19, 19), rgb(242, 242, 242)) 10%)]",
            isEmphasized: $03960a2740ca2b19$var$selectedActiveBackground
        },
        isHovered: {
            default: "[color-mix(in srgb, light-dark(rgb(255, 255, 255), rgb(17, 17, 17)), light-dark(rgb(19, 19, 19), rgb(242, 242, 242)) 10%)]",
            isEmphasized: $03960a2740ca2b19$var$selectedActiveBackground
        },
        isPressed: {
            default: "[color-mix(in srgb, light-dark(rgb(255, 255, 255), rgb(17, 17, 17)), light-dark(rgb(19, 19, 19), rgb(242, 242, 242)) 10%)]",
            isEmphasized: $03960a2740ca2b19$var$selectedActiveBackground
        }
    },
    forcedColors: {
        default: 'Background'
    }
};
const $03960a2740ca2b19$var$treeRow = function anonymous(props) {
    let rules = " ";
    rules += ' _Pc91';
    rules += ' sd91';
    rules += ' Fv91';
    rules += ' Za91';
    rules += ' _oa91';
    rules += ' ug91';
    rules += ' uch91';
    rules += ' udi91';
    rules += ' uea91';
    rules += ' ugb91';
    rules += ' uhd91';
    rules += ' uje91';
    rules += ' uic91';
    rules += ' vd91';
    rules += ' vsf91';
    rules += ' wb91';
    rules += ' xb91';
    rules += ' _xa91';
    rules += ' _Fa91';
    rules += ' _Ffb91';
    rules += ' pt91';
    rules += ' _Le91';
    if (props.isLink) rules += ' ry91';
    else rules += ' ri91';
    if (props.isSelected) {
        if (props.isPressed) {
            if (props.isEmphasized) rules += ' -qH4xad-gT9rOHd91';
            else rules += ' -qH4xad-gRfT7e91';
        } else if (props.isHovered) {
            if (props.isEmphasized) rules += ' -qH4xad-gT9rOHd91';
            else rules += ' -qH4xad-gRfT7e91';
        } else if (props.isFocusVisibleWithin) {
            if (props.isEmphasized) rules += ' -qH4xad-gT9rOHd91';
            else rules += ' -qH4xad-gRfT7e91';
        } else if (props.isEmphasized) rules += ' -qH4xad-gJpow3b91';
        else rules += ' -qH4xad-gj1B7i91';
    } else if (props.isPressed) rules += ' -qH4xad-gRfT7e91';
    else if (props.isHovered) rules += ' -qH4xad-gj1B7i91';
    else if (props.isFocusVisibleWithin) rules += ' -qH4xad-gj1B7i91';
    else rules += ' -qH4xad-gEzkoQe91';
    rules += ' -qH4xad-lga91';
    rules += ' -_34HbNb-Oh91';
    rules += ' -_34HbNb-lOc91';
    return rules;
};
const $03960a2740ca2b19$var$treeCellGrid = function anonymous(props) {
    let rules = " ";
    rules += ' se91';
    rules += ' Za91';
    rules += ' Fb91';
    rules += ' _oa91';
    rules += ' _cb91';
    rules += ' eb91';
    rules += ' Dw9uTxc91';
    rules += ' EM8Mfn91';
    rules += ' CgjMZ2c91';
    rules += ' gs9yXOb91';
    rules += ' Rp91';
    if (props.isDisabled) {
        rules += ' pp91';
        rules += ' plc91';
    }
    if (props.isFocusVisible) rules += ' -_7xg3bb-Oh91';
    else rules += ' -_7xg3bb-O8Izf8c91';
    rules += ' -_7xg3bb-lOc91';
    rules += ' -pKMv1c-Oh91';
    rules += ' -pKMv1c-lOc91';
    if (props.isDetached) {
        if (props.isSelected) rules += ' iBGbjub91';
        else rules += ' iA91';
    }
    if (props.isDetached) rules += ' _kb91';
    if (props.isDetached) rules += ' hb91';
    if (props.isDetached) rules += ' mb91';
    if (props.isDetached) rules += ' lb91';
    if (props.isDetached) rules += ' ob91';
    if (props.isDetached) rules += ' nb91';
    if (props.isDetached) rules += ' kb91';
    if (props.isDetached) rules += ' jb91';
    if (props.isDetached) rules += ' _jf91';
    return rules;
};
const $03960a2740ca2b19$var$treeCheckbox = " zoRzcu91 yoRzcu91 BoRzcu91 AoRzcu91 Ix91 Hy91 Rd91";
const $03960a2740ca2b19$var$treeIcon = " z2U5Crc91 y2U5Crc91 B2U5Crc91 A2U5Crc91 Ht91 Hsu91 -_8sjo0b-t5ZbAob91";
const $03960a2740ca2b19$var$treeContent = " zk52g2d91 yk52g2d91 Bk52g2d91 Ak52g2d91 _Yb91 _7c91 _Nc91 Pc91";
const $03960a2740ca2b19$var$treeActions = " zkG38H91 ykG38H91 BkG38H91 AkG38H91 Ir91 Hs91";
const $03960a2740ca2b19$var$treeActionMenu = " z6Nrfjc91 y6Nrfjc91 B6Nrfjc91 A6Nrfjc91";
const $03960a2740ca2b19$var$cellFocus = {
    outlineStyle: {
        default: 'none',
        isFocusVisible: 'solid'
    },
    outlineOffset: -2,
    outlineWidth: 2,
    outlineColor: 'focus-ring',
    borderRadius: '[6px]'
};
const $03960a2740ca2b19$var$treeRowFocusIndicator = "tDhuzb";
const $03960a2740ca2b19$export$6e77ea6719814e9c = (props)=>{
    let { href: href } = props;
    let { isDetached: isDetached, isEmphasized: isEmphasized } = (0, $iOVFT$useContext)($03960a2740ca2b19$var$InternalTreeContext);
    return /*#__PURE__*/ (0, $iOVFT$jsx)((0, $iOVFT$TreeItem), {
        ...props,
        className: (renderProps)=>$03960a2740ca2b19$var$treeRow({
                ...renderProps,
                isLink: !!href,
                isEmphasized: isEmphasized
            }) + (renderProps.isFocusVisible && !isDetached ? ' ' + $03960a2740ca2b19$var$treeRowFocusIndicator : '')
    });
};
const $03960a2740ca2b19$export$9a5779ed3fade674 = (props1)=>{
    let { children: children } = props1;
    let { isDetached: isDetached, isEmphasized: isEmphasized } = (0, $iOVFT$useContext)($03960a2740ca2b19$var$InternalTreeContext);
    let scale = (0, $859432f3b3573fcb$export$a8d2043b2d807f4d)();
    return /*#__PURE__*/ (0, $iOVFT$jsx)((0, $iOVFT$TreeItemContent), {
        children: ({ isExpanded: isExpanded, hasChildItems: hasChildItems, selectionMode: selectionMode, selectionBehavior: selectionBehavior, isDisabled: isDisabled, isFocusVisible: isFocusVisible, isSelected: isSelected, id: id, state: state })=>{
            let isNextSelected = false;
            let isNextFocused = false;
            let keyAfter = state.collection.getKeyAfter(id);
            if (keyAfter != null) isNextSelected = state.selectionManager.isSelected(keyAfter);
            let isFirst = state.collection.getFirstKey() === id;
            return /*#__PURE__*/ (0, $iOVFT$jsxs)("div", {
                className: $03960a2740ca2b19$var$treeCellGrid({
                    isDisabled: isDisabled,
                    isNextSelected: isNextSelected,
                    isSelected: isSelected,
                    isFirst: isFirst,
                    isNextFocused: isNextFocused,
                    isDetached: isDetached
                }),
                children: [
                    selectionMode !== 'none' && selectionBehavior === 'toggle' && // TODO: add transition?
                    /*#__PURE__*/ (0, $iOVFT$jsx)("div", {
                        className: $03960a2740ca2b19$var$treeCheckbox,
                        children: /*#__PURE__*/ (0, $iOVFT$jsx)((0, $9b405e0f8095dce0$export$48513f6b9f8ce62d), {
                            isEmphasized: isEmphasized,
                            slot: "selection"
                        })
                    }),
                    /*#__PURE__*/ (0, $iOVFT$jsx)("div", {
                        className: " z7fSmKc91 y7fSmKc91 B7fSmKc91 A7fSmKc91 ZecPNad91"
                    }),
                    /*#__PURE__*/ (0, $iOVFT$jsx)($03960a2740ca2b19$var$ExpandableRowChevron, {
                        isDisabled: isDisabled,
                        isExpanded: isExpanded,
                        scale: scale,
                        isHidden: !hasChildItems
                    }),
                    /*#__PURE__*/ (0, $iOVFT$jsx)((0, $iOVFT$Provider), {
                        values: [
                            [
                                (0, $8e847109a6ab556d$export$9afb8bc826b033ea),
                                {
                                    styles: $03960a2740ca2b19$var$treeContent
                                }
                            ],
                            [
                                (0, $ac8c32e6775ddd1f$export$a49f528ae1a4d0ed),
                                {
                                    render: (0, $1f4b04be3f24aae3$export$9d7e2342a7e53afa)({
                                        slot: 'icon',
                                        styles: $03960a2740ca2b19$var$treeIcon
                                    }),
                                    styles: " ZuUmpre91 FuUmpre91 _va91"
                                }
                            ],
                            [
                                (0, $10401bdc118cbc90$export$33f5f2f2cb85d743),
                                {
                                    styles: $03960a2740ca2b19$var$treeActions
                                }
                            ],
                            [
                                (0, $8bf3cd2442eb485e$export$7f4b66acaca28bd5),
                                {
                                    styles: $03960a2740ca2b19$var$treeActionMenu,
                                    isQuiet: true
                                }
                            ]
                        ],
                        children: children
                    }),
                    isFocusVisible && isDetached && /*#__PURE__*/ (0, $iOVFT$jsx)("div", {
                        role: "presentation",
                        className: function anonymous(props) {
                            let rules = " ";
                            if (props.isFocusVisible) rules += ' _Lf91';
                            else rules += ' _Le91';
                            rules += ' _Kb91';
                            rules += ' _Mc91';
                            rules += ' Oh91';
                            rules += ' of91';
                            rules += ' nf91';
                            rules += ' kf91';
                            rules += ' jf91';
                            rules += ' _Pa91';
                            rules += ' Wr91';
                            rules += ' _lr91';
                            rules += ' _Ar91';
                            rules += ' _zr91';
                            return rules;
                        }({
                            isFocusVisible: true
                        })
                    })
                ]
            });
        }
    });
};
const $03960a2740ca2b19$var$expandButton = function anonymous(props) {
    let rules = " ";
    rules += ' z8dW5Qb91';
    rules += ' y8dW5Qb91';
    rules += ' B8dW5Qb91';
    rules += ' A8dW5Qb91';
    if (props.isDisabled) {
        rules += ' pp91';
        rules += ' plc91';
    } else rules += ' p40ub4c91';
    rules += ' Fv91';
    rules += ' Zw91';
    rules += ' sd91';
    rules += ' _wb91';
    rules += ' _cb91';
    rules += ' _Ca91';
    rules += ' _Le91';
    rules += ' ri91';
    if (props.isExpanded) {
        if (props.isRTL) rules += ' _Za91';
        else rules += ' _Zb91';
    }
    rules += ' Td91';
    rules += ' Qd91';
    rules += ' Sd91';
    rules += ' Rd91';
    rules += ' Yd91';
    rules += ' Xb91';
    rules += ' _2b91';
    rules += ' g991';
    rules += ' _je91';
    rules += ' __ca91';
    if (props.isHidden) rules += ' _6b91';
    return rules;
};
function $03960a2740ca2b19$var$ExpandableRowChevron(props1) {
    let expandButtonRef = (0, $iOVFT$useRef)(null);
    let [fullProps, ref] = (0, $iOVFT$useContextProps)({
        ...props1,
        slot: 'chevron'
    }, expandButtonRef, (0, $iOVFT$ButtonContext));
    let { isExpanded: isExpanded, scale: scale, isHidden: isHidden } = fullProps;
    let { direction: direction } = (0, $iOVFT$useLocale)();
    return /*#__PURE__*/ (0, $iOVFT$jsx)((0, $iOVFT$Button), {
        ...props1,
        ref: ref,
        slot: "chevron",
        className: (renderProps)=>$03960a2740ca2b19$var$expandButton({
                ...renderProps,
                isExpanded: isExpanded,
                isRTL: direction === 'rtl',
                scale: scale,
                isHidden: isHidden
            }),
        children: /*#__PURE__*/ (0, $iOVFT$jsx)((0, $4b69f02ec06b9226$export$2e2bcd8739ae039), {
            className: function anonymous(props) {
                let rules = " ";
                if (props.direction === "rtl") {
                    rules += ' -Z4Pn4c-a91';
                    rules += ' __Ha91';
                } else if (props.direction === "ltr") {
                    rules += ' -Z4Pn4c-b91';
                    rules += ' __Ha91';
                }
                if (props.direction === "rtl") {
                    rules += ' -_04Pn4c-a91';
                    rules += ' __Ha91';
                } else if (props.direction === "ltr") {
                    rules += ' -_04Pn4c-b91';
                    rules += ' __Ha91';
                }
                rules += ' -_8sjo0b-t5ZbAob91';
                return rules;
            }({
                direction: direction
            })
        })
    });
}
/**
 * A tree view provides users with a way to navigate nested hierarchical information.
 */ const $03960a2740ca2b19$export$6940b0d9c820eca7 = /*#__PURE__*/ (0, $iOVFT$forwardRef)($03960a2740ca2b19$var$TreeView);


export {$03960a2740ca2b19$export$6e77ea6719814e9c as TreeViewItem, $03960a2740ca2b19$export$9a5779ed3fade674 as TreeViewItemContent, $03960a2740ca2b19$export$6940b0d9c820eca7 as TreeView};
//# sourceMappingURL=TreeView.mjs.map
